/*
 * Nameday   ver  2.0.1  2003-11-02
 * Copyright (c) 2002-2003 by Michal Nazarewicz (mina86@tlen.pl)
 *
 * This script is free software; It is ditributed under terms of
 * GNU Lesser General Public License. Copy of the license can be found
 * at www.gnu.org/licenses/licenses.html#LGPL
 *
 * Visit www.projektcode.prv.pl for more..
 */


//
// Tuday's date :)
//
var nameday_date = new Date(),
	nameday_day = nameday_date.getDate(),
	nameday_month = nameday_date.getMonth()+1;



//
// Object representing names
//
function NamedayNames(names) {
	if (names instanceof Array) {
		this.names = names;
	} else {
		this.names = names.split('|');
	}
}

NamedayNames.prototype = {
	join: function(sep, last_sep, limit) {
		// Init args
		switch (arguments.length) {
			case  0: sep = null;
			case  1: last_sep = null;
			case  2: limit = null;
			case  3: break;
			default: return false;
		}


		// Get names
		var names = this.getNames(limit);


		// Join
		if (sep==null) {
			sep = ', ';
		}
		if (last_sep==null) {
			return names.join(sep);
		} else {
			var str = '';
			for (var i = 0; i<names.length; i++) {
				if (i==names.length-1) {
					str += last_sep;
				} else if (i) {
					str += sep;
				}
				str += names[i];
			}
			return str;
		}
	},


	//
	// Returns names as formated string
	//
	toString: function(before, after, sep, last_sep, limit) {
		// Init args
		switch (arguments.length) {
			case  0: before = null;
			case  1: after = null;
			case  2: sep = null;
			case  3: last_sep = null;
			case  4: limit = null;
			case  5: break;
			default: return false;
		}


		// Join names
		var str = this.join(sep, last_sep, limit);
		if (!str) {
			return false;
		}


		// Return
		return (before==null?'':before) + str + (after==null?'':after);
	},


	//
	// Returns names in array (maximum number of names in array is limit
	// or there's no maximum number if limit==0 || limit==null)
	//
	getNames: function(limit) {
		// Check args;
		if (arguments.length>1) {
			return false;
		}

		// All requested
		if (arguments.length==0 || limit==null || limit<1 ||
			limit>=this.names.length) {
			return this.names;

		// Limit requested
		} else {
			var arr = new Array(limit);
			for (var i = 0; i<limit; i++) {
				arr[i] = names[i];
			}
			return arr;
		}
	},


	//
	// Get name at index
	//
	get: function(index) {
		return this.names[index];
	},


	//
	// Get number of names
	//
	count: function() {
		return this.names.length;
	}
};



//
// Object representing set of names for each day of year
//
function NamedaySet(array) {
	this.array = array;
}

NamedaySet.prototype = {
	//
	// Returns NamedayNames object with names of people who have nameday
	// today or in the dth of m  If d or m is null or omitted, todays day
	// and/or month is taken.
	// Note: Months are indexed from 1 !!
	//
	getNames: function(d, m) {
		switch (arguments.length) {
			case  0: d = null;
			case  1: m = null;
			case  2: break;
			default: return false;
		}

		if (d==null) {
			d = nameday_day;
		}
		if (m==null) {
			m = nameday_month;
		}

		return new NamedayNames(this.array[m-1][d-1]);
	}
};




//
// Main object
//
function Nameday() {
	this.sets = new Array();
}


Nameday.prototype = {
	//
	// Returns specyfied set
	//
	getSet: function(lang) {
		if (arguments.length!=1) {
			return false;
		}
		return this.sets['' + lang];
	},


	//
	// Adds set
	//
	addSet: function(lang, set) {
		if (arguments.length!=2) {
			return false;
		}
		if (set instanceof NamedaySet) {
			this.sets['' + lang] = set;
		} else {
			this.sets['' + lang] = new NamedaySet(set);
		}
	}
};

var nameday = new Nameday();



/*
 * Nameday Polish Extension  ver  1.4.2  2003-11-19
 * Copyright (c) 2002-2003 by Michal Nazarewicz (mina86@tlen.pl)
 *
 * This script is free software; It is ditributed under terms of
 * GNU Lesser General Public License. Copy of the license can be found
 * at www.gnu.org/licenses/licenses.html#LGPL
 */


//
// Converts names
//
NamedayNames.prototype.pl_convert = function(method) {
	if (arguments.length!=1) {
		return false;
	}
	if (method==0) {
		return new NamedayNames(this.names);
	}
	if (method!=1) {
		return false;
	}

	var ret = new Array(), name = '';
	for (var i = 0; i<this.names.length; i++) {
		name = this.names[i];

		var len = name.length,
			last3 = name.substring(len-3),
			last2 = name.substring(len-2),
			vowel3 = "aeiouy".indexOf(name.charAt(len-4))!=-1,
			vowel2 = "aeiouy".indexOf(name.charAt(len-3))!=-1;

		if (last3=="ego") {
			if (name.substring(len-4, 1)=='l') {
				name = name.substring(0, len-3);
			} else {
				name = name.substring(0, len-3) + "y";
			}
		} else if (last3=="ca") {
			name = name.substring(0, len-3) + "niec";
		} else if (last3=="tra") {
			name = name.substring(0,len-3) + (vowel3?"tr":"ter");
		} else if (last2=="ka" && !vowel2) {
			name =  name.substring(0,len-2) + "ek";
		} else if (last2=="a" && !vowel2) {
			name = name.substring(0, len-2) + "a";
		} else {
			name = name.substring(0, len-1) +
				(last2.substring(2,1)=='a'?'':'a');
		}

		ret[i] = name;
	}
	return new NamedayNames(ret);
};


//
// For backward compatibility
//
function WypiszImieniny(before, after, sep, last_sep, method) {
	switch (arguments.length) {
		case 0: before = null;
		case 1: after = null;
		case 2: sep = null;
		case 3: last_sep = null;
		case 3: method = null;
	}


	var names = PobierzImieniny(sep, last_sep, method);
	if (!names) {
		return false;
	}


	document.write("" + before + names + after);
	return true;
}

function PobierzImieniny(sep, last_sep, method) {
	switch (arguments.length) {
		case 0: sep = null;
		case 1: last_sep = null;
		case 2: method = null;
	}
	if (method==null) {
		method = 0;
	}

	var names;
	if (!(names = nameday.getSet('pl')) || !(names = names.getNames()) ||
		!(names = names.pl_convert(method))) {
		return false;
	}

	return names.toString('', '', sep, last_sep);
}



/*
 * Nameday Polish Names Database  v 2.1
 * Database taken from infoludek.pl/~slawek/imieniny.html
 * +some corrections
 */


nameday.addSet('pl', new Array(
	new Array(
		"Masawa|Mieczysawa|Mieszka",
		"Bazylego|Makarego|Narcyzy",
		"Arlety|Danuty|Lucjana",
		"Anieli|Elbiety|Tytusa",
		"Edwarda|Hanny|Szymona",
		"Kacpra|Melchiora|Baltazara",
		"Juliana|Lucjana|Walentyny",
		"Artura|Rajmunda|Seweryny",
		"Adriana|Alicji|Teresy",
		"Ady|Jana|Wilhelma",
		"Feliksa|Honoraty|Marty",
		"Bernarda|Czesawy|Grety",
		"Bogumia|Bogumiy|Weroniki",
		"Feliksa|Hilarego|Martyny",
		"Arnolda|Dory|Pawa",
		"Marcelego|Walerii|Wodzimierza",
		"Antoniego|Henryki|Mariana",
		"Beatrycze|Magorzaty|Piotra",
		"Erwiny|Henryka|Mariusza",
		"Fabioli|Miy|Sebastiana",
		"Agnieszki|Jarosawa|Nory",
		"Dominiki|Mateusza|Wincentego",
		"Fernandy|Jana|Rajmundy",
		"Felicji|Roberta|Sawy",
		"Miosza|Pawa|Tatiany",
		"Lutosawa|Normy|Pauliny",
		"Anieli|Juliana|Przemysawa",
		"Agnieszki|Kariny|Lesawa",
		"Franciszka|Konstancji|Salomei",
		"Martyny|Macieja|Teofila",
		"Joanny|Ksawerego|Luizy"
	),
	new Array(
		"Brygidy|Dobrogniewa|Ignacego",
		"Kornela|Marii|Mirosawy",
		"Baeja|Joanny|Telimeny",
		"Andrzeja|Mariusza|Weroniki",
		"Agaty|Filipa|Justyniana",
		"Amandy|Bogdana|Doroty",
		"Ryszarda|Teodora|Wilhelminy",
		"Irminy|Piotra|Sylwii",
		"Bernarda|Eryki|Rajmunda",
		"Elwiry|Elizy|Jacka",
		"Bernadetty|Marii|Olgierda",
		"Czasawa|Damiana|Normy",
		"Grzegorza|Lesawa|Katarzyny",
		"Liliany|Walentyny|Walentego",
		"Arnolda|Jowity|Georginy",
		"Danuty|Daniela|Juliany",
		"Donata|Gizeli|ukasza",
		"Konstancji|Krystiana|Sylwany",
		"Bettiny|Konrada|Mirosawa",
		"Anety|Lecha|Leona",
		"Eleonory|Lenki|Kiejstuta",
		"Magorzaty|Marty|Nikifora",
		"Damiana|Romana|Romany",
		"Boguty|Bogusza|Macieja",
		"Almy|Cezarego|Jarosawa",
		"Bogumia|Eweliny|Mirosawa",
		"Gagrieli|Liwii|Leonarda",
		"Ludomira|Makarego|Wiliany",
		"Lecha|Lutomira|Wiktora"
	),
	new Array(
		"Albina|Antoniny|Radosawy",
		"Halszki|Heleny|Karola",
		"Kingi|Maryna|Tycjana",
		"Adrianny|Kazimierza|Wacawa",
		"Aurory|Fryderyka|Oliwii",
		"Jordana|Marcina|Ry",
		"Flicyty|Kajetana|Pauli",
		"Beaty|Juliana|Wincentego",
		"Dominika|Franciszki|Katarzyny",
		"Boysawy|Cypriana|Marcelego",
		"Konstantego|Ludosawa|Rozyny",
		"Grzegorza|Justyny|Jzefiny",
		"Boeny|Krystyny|Marka",
		"Dalii|Leona|Matyldy",
		"Delfiny|Longina|Ludwiki",
		"Izabeli|Henryka|Oktawii",
		"Reginy|Patryka|Zdyszka",
		"Edwarda|Narcyza|Zbysawa",
		"Aleksandryny|Jzefa|Nicety",
		"Joachima|Kiry|Maurycego",
		"Benedykta|Lubomiry|Lubomira",
		"Bogusawa|Jagody|Katarzyny",
		"Feliksa|Konrada|Zbysawy",
		"Gabrieli|Marka|Seweryna",
		"Bolka|Cezaryny|Marioli",
		"Dory|Olgi|Teodora",
		"Ernesta|Jana|Marka",
		"Anieli|Kasrota|Soni",
		"Marka|Wiktoryny|Zenona",
		"Amelii|Dobromira|Leonarda",
		"Balbiny|Kamila|Kornelii"
	),
	new Array(
		"Chryzamtyny|Grayny|Zygmunta",
		"Franciszka|Malwiny|Wadysawa",
		"Pankracego|Renaty|Ryszarda",
		"Benedykta|Izodory|Wacawy",
		"Ireny|Kleofasa|Wincentego",
		"Ady|Celestyny|Ireneusza",
		"Donata|Herminy|Rufina",
		"Amadeusza|Cezaryny|Juliany",
		"Mai|Marcelego|Wadima",
		"Borysawy|makarego|Michaa",
		"Filipa|Izoldy|Leona",
		"Juliusza|Lubosawa|Wiktoryny",
		"Artemona|Justyny|Przemysawy",
		"Bernarda|Martyny|Waleriana",
		"Adolfiny|Odetty|Wacawa",
		"Bernarda|Biruty|Erwina",
		"Anicety|Klary|Rudolfina",
		"Apoloniusza|Bogusawy|Gocisawy",
		"Alfa|Leonii|Tytusa",
		"Agnieszki|Amalii|Czecha",
		"Jarosawa|Konrada|Selmy",
		"ukasza|Kai|Nastazji",
		"Ilony|Jerzego|Wojciecha",
		"Bony|Horacji|Jerzego",
		"Jarosawa|Marka|Wiki",
		"Marii|Marzeny|Ryszarda",
		"Sergiusza|Teofila|Zyty",
		"Bogny|Walerii|Witalisa",
		"Hugona|Piotra|Roberty",
		"Balladyny|Lilli|Mariana"
	),
	new Array(
		"Jzefa|Lubomira|Ramony",
		"Longiny|Toli|Zygmunta",
		"Jaropeka|Marii|Niny",
		"Floriana|Michaa|Moniki",
		"Irydy|Tamary|Waldemara",
		"Beniny|Filipa|Judyty",
		"Augusta|Gizeli|Ludomiry",
		"Kornela|Lizy|Stanisawa",
		"Grzegorza|Karoliny|Karola",
		"Antoniny|Izydory|Jana",
		"Igi|Mamerta|Miry",
		"Dominika|Imeldy|Pankracego",
		"Agnieszki|Magdaleny|Serwacego",
		"Bonifacego|Julity|Macieja",
		"Dionizego|Nadziei|Zofii",
		"Andrzeja|Jdrzeja|Magorzaty",
		"Brunony|Sawomira|Wery",
		"Alicji|Edwina|Eryka",
		"Celestyny|Iwony|Piotra",
		"Bazylego|Bernardyna|Krystyny",
		"Jana|Moniki|Wiktora",
		"Emila|Neleny|Romy",
		"Leoncjusza|Michaa|Renaty",
		"Joanny|Zdenka|Zuzanny",
		"Borysa|Magdy|Marii-Magdaleny",
		"Eweliny|Jana|Pawa",
		"Amandy|Jana|Juliana",
		"Augustyna|Ingi|Jaromira",
		"Benity|Maksymiliana|Teodozji",
		"Ferdynanda|Gryzeldy|Zyndrama",
		"Anieli|Feliksa|Kamili"
	),
	new Array(
		"Gracji|Jakuba|Konrada",
		"Erazma|Marianny|Marzeny",
		"Anatola|Leszka|Tamary",
		"Christy|Helgi|Karola",
		"Bonifacego|Kiry|Waltera",
		"Laury|Laurentego|Nory",
		"Ariadny|Jarosawa|Roberta",
		"Ady|Celii|Medarda",
		"Anny-Marii|Felicjana|Sawoja",
		"Bogumia|Diany|Magorzaty",
		"Barnaby|Benedykta|Flory",
		"Gwidona|Leonii|Niny",
		"Antoniego|Gracji|Lucjana",
		"Bazylego|Elizy|Justyny",
		"Jolanty|Lotara|Wita",
		"Aliny|Anety|Benona",
		"Laury|Leszka|Marcjana",
		"Elbiety|Marka|Pauli",
		"Gerwazego|Protazego|Sylwii",
		"Bogny|Rafaeli|Rafaa",
		"Alicji|Alojzego|Rudolfa",
		"Pauliny|Sabiny|Tomasza",
		"Albina|Wandy|Zenona",
		"Danuty|Jana|Janiny",
		"ucji|Witolda|Wilhelma",
		"Jana|Pauliny|Rudolfiny",
		"Cypriana|Emanueli|Wadysawa",
		"Florentyny|Ligii|Leona",
		"Pawa|Piotra|Salomei",
		"Arnolda|Emiliany|Lucyny"
	),
	new Array(
		"Bogusza|Haliny|Mariana",
		"Kariny|Serafiny|Urbana",
		"Anatola|Jacka|Mirosawy",
		"Aureli|Malwiny|Zygfryda",
		"Antoniego|Bartomieja|Karoliny",
		"Dominiki|Jaropeka|ucji",
		"Estery|Kiry|Rudolfa",
		"Arnolda|Edgara|Elbiety",
		"Hieronima|Palomy|Weroniki",
		"Filipa|Sylwany|Witalisa",
		"Benedykta|Kariny|Olgi",
		"Brunona|Jana|Wery",
		"Danieli|Irwina|Magorzaty",
		"Kamili|Kamila|Marcelego",
		"Henryka|Igi|Wodzimierza",
		"Eustachego|Mariki|Mirelli",
		"Aleksego|Bogdana|Martyny",
		"Kamila|Karoliny|Roberta",
		"Alfreny|Rufina|Wincentego",
		"Fryderyka|Magorzaty|Seweryny",
		"Danieli|Wawrzyca|Wiktora",
		"Magdaleny|Mileny|Wawrzyca",
		"Sawy|Sawosza|elisawy",
		"Kingi|Krystyna|Michaliny",
		"jakuba|Krzysztofa|Walentyny",
		"Anny|Mirosawy|Joachima",
		"Aureliusza|Natalii|Rudolfa",
		"Ady|Wiwiany|Sylwiusza",
		"Marty|Konstantego|Olafa",
		"Julity|Ludmiy|Zdobysawa",
		"Ignacego|Lodomiry|Romana"
	),
	new Array(
		"Jarosawa|Justyny|Nadziei",
		"Gustawa|Kariny|Stefana",
		"Augustyna|Kamelii|Lidii",
		"Dominiki|Dominika|Protazego",
		"Emila|Karoliny|Kary",
		"Jakuba|Sawy|Wincentego",
		"Donaty|Olechny|Kajetana",
		"Izy|Rajmunda|Seweryna",
		"Klary|Romana|Rozyny",
		"Bianki|Borysa|Wawrzyca",
		"Luizy|Wodzmierza|Zuzanny",
		"Hilarii|Juliana|Lecha",
		"Elwiry|Hipolita|Radosawy",
		"Alfreda|Maksymiliana|Selmy",
		"Marii|Napoleona|Stelli",
		"Joachima|Nory|Stefana",
		"Anity|Elizy|Mirona",
		"Bogusawa|Bronisawa|Ilony",
		"Emilii|Julinana|Konstancji",
		"Bernarda|Sabiny|Samuela",
		"Franciszka|Kazimiery|Ruty",
		"Cezarego|Marii|Zygfryda",
		"Apolinarego|Miy|Ry",
		"Bartosza|Jerzego|Maliny",
		"Belii|Ludwika|Luizy",
		"Ireneusza|Konstantego|Marii",
		"Cezarego|Magorzaty|Moniki",
		"Adeliny|Erazma|Sobiesawa",
		"Beaty|Racibora|Sabiny",
		"Benona|Jowity|Szczsnego",
		"Cyrusa|Izabeli|Rajmundy"
	),
	new Array(
		"Belindy|Bronisza|Idziego",
		"Dionizy|Izy|Juliana",
		"Joachima|Liliany|Szymona",
		"Dalii|Idy|Rocha",
		"Doroty|Justyna|Wawrzyca",
		"Beaty|Eugeniusza|Lidy",
		"Reginy|Marka|Melchiora",
		"Czcibora|Marii|Radosawa",
		"Aldony|Jakuba|Sergiusza",
		"Eligii|Irmy|ukasza",
		"Dagny|Jacka|Prota",
		"Amadeusza|Gwidy|Sylwiny",
		"Apolinarego|Eugenii|Lubomira",
		"Bernarda|Mony|Roksany",
		"Albina|Lolity|Ronalda",
		"Jagienki|Kamili|Korneliusza",
		"Franciszka|Lamberty|Narcyza",
		"Ireny|Irminy|Stanisawa",
		"Januarego|Konstancji|Leopolda",
		"Eustachego|Faustyny|Renaty",
		"Darii|Mateusza|Wawrzyca",
		"Maury|Milany|Tomasza",
		"Bogusawa|Liwiusza|Tekli",
		"Dory|Gerarda|Maryny",
		"Aureli|Kamila|Kleofasa",
		"Cypriana|Justyny|ucji",
		"Damiana|Mirabeli|Wincentego",
		"Libuszy|Wacawy|Wacawa",
		"Michaliny|Michaa|Rafaa",
		"Geraldy|Honoriusza|Wery"
	),
	new Array(
		"Heloizy|Igora|Remigiusza",
		"Racheli|Sawy|Teofila",
		"Bogumia|Gerarda|Jzefy",
		"Edwina|Rosawy|Rozalii",
		"Flawii|Justyna|Rajmunda",
		"Artura|Fryderyki|Petry",
		"Krystyna|Marii|Marka",
		"Brygidy|Loreny|Marcina",
		"Arnolda|Ludwika|Sybili",
		"Franciszka|Loretty|Poli",
		"Aldony|Brunona|Emila",
		"Krystyny|Maksa|Serafiny",
		"Edwarda|Geraldyny|Teofila",
		"Alany|Damiana|Liwii",
		"Jadwigi|Leonarda|Teresy",
		"Ambroego|Florentyny|Gawa",
		"Antonii|Ignacego|Wiktora",
		"Hanny|Klementyny|ukasza",
		"Michaliny|Michaa|Piotra",
		"Ireny|Kleopatry|Witalisa",
		"Celiny|Hilarego|Janusza",
		"Haliszki|Lody|Przybysawa",
		"Edwarda|Marleny|Seweryna",
		"Arety|Marty|Marcina",
		"Ingi|Maurycego|Sambora",
		"Ewarysta|Lucyny|Lutosawy",
		"Iwony|Noemi|Szymona",
		"Narcyza|Serafina|Wioletty",
		"Angeli|Przemysawa|Zenobii",
		"Augustyny|ukasza|Urbana",
		"Krzysztofa|Augusta|Saturnina"
	),
	new Array(
		"Konrada|Seweryny|Wiktoryny",
		"Bohdany|Henryka|Tobiasza",
		"Huberta|Miy|Sylwii",
		"Albertyny|Karola|Olgierda",
		"Balladyny|Elbiety|Sawomira",
		"Arletty|Feliksa|Leonarda",
		"Antoniego|Kaliny|Przemiy",
		"Klaudii|Seweryna|Wiktoriusza",
		"Anatolii|Gracji|Teodora",
		"Leny|Lubomira|Natalii",
		"Bartomieja|Gertrudy|Marcina",
		"Konrada|Renaty|Witolda",
		"Arkadii|Krystyna|Stanisawy",
		"Emila|Laury|Rogera",
		"Amielii|Idalii|Leopolda",
		"Edmunda|Marii|Marka",
		"Grzegorza|Salomei|Walerii",
		"Klaudyny|Romana|Tomasza",
		"Elbiety|Faustyny|Pawa",
		"Anatola|Edyty|Rafaa",
		"Janusza|Marii|Reginy",
		"Cecylii|Jonatana|Marka",
		"Adeli|Felicyty|Klemensa",
		"Emmy|Flory|Romana",
		"Elbiety|Katarzyny|Klemensa",
		"Leona|Leonarda|Lesawy",
		"Franciszka|Kseni|Maksymiliana",
		"Jakuba|Stefana|Romy",
		"Baeja|Margerity|Saturnina",
		"Andrzeja|Maury|Ondraszka"
	),
	new Array(
		"Blanki|Edmunda|Eligiusza",
		"Balbiny|Ksawerego|Pauliny",
		"Hilarego|Franciszki|Ksawery",
		"Barbary|Hieronima|Krystiana",
		"Kryspiny|Norberta|Sabiny",
		"Dionizji|Leontyny|Mikoaja",
		"Agaty|Dalii|Sobiesawa",
		"Delfiny|Marii|Wirginiusza",
		"Anety|Leokadii|Wiesawa",
		"Danieli|Bohdana|Julii",
		"Biny|Damazego|Waldemara",
		"Ady|Aleksandra|Dagmary",
		"Dalidy|Juliusza|ucji",
		"Alfreda|Izydora|Zoriny",
		"Celiny|Ireneusza|Niny",
		"Albiny|Sebastiana|Zdzisawy",
		"Jolanty|ukasza|Olimpii",
		"Bogusawa|Gracjana|Laury",
		"Beniaminy|Dariusza|Gabrieli",
		"Bogumiy|Dominika|Zefiryna",
		"Honoraty|Seweryny|Tomasza",
		"Boeny|Drogomira|Zenona",
		"Dagny|Sawomiry|Wiktora",
		"Adama|Ewy|Irminy",
		"Anety|Glorii|Piotra",
		"Dionizego|Kaliksta|Szczepana",
		"Fabioli|Jana|anety",
		"Antoniusza|Cezarego|Teofilii",
		"Dawida|Dionizy|Tomasza",
		"Eugeniusza|Katarzyny|Sabiny",
		"Mariusza|Melanii|Sylwestra"
	)
));
